pub fn load_configuration_from_file(
path: &Path,
) -> Result<Configuration, ConfigError>Expand description
Load configuration from an explicit file path.
Errors
Returns an error if the file cannot be read or parsed.
pub fn load_configuration_from_file(
path: &Path,
) -> Result<Configuration, ConfigError>Load configuration from an explicit file path.
Returns an error if the file cannot be read or parsed.